@@ -50,16 +50,28 @@ class Action:
     CYCLE_UP_LIGHT_BRIGHTNESS = "CycleUpLightBrightness"
     CYCLE_DOWN_LIGHT_BRIGHTNESS = "CycleDownLightBrightness"
     CYCLE_BRIGHTNESS = "CycleBrightness"
+    CYCLE_COLOR_TEMP = "CycleColorTemp"
+    SET_COLOR_TEMP = "SetColorTemp"
+    CYCLE_COLOR_TEMP_PRESET = "CycleColorTempPreset"
+    DECREASE_COLOR_TEMP = "DecreaseColorTemp"
+    INCREASE_COLOR_TEMP = "IncreaseColorTemp"
 
     # Fans
-    SET_SPEED = "SetSpeed"
-    INCREASE_SPEED = "IncreaseSpeed"
-    DECREASE_SPEED = "DecreaseSpeed"
-    BREEZE_ON = "BreezeOn"
     BREEZE_OFF = "BreezeOff"
+    BREEZE_ON = "BreezeOn"
+    DECREASE_SPEED = "DecreaseSpeed"
+    DIM_MODE = "DimMode"
+    INCREASE_SPEED = "IncreaseSpeed"
+    OEM_HOME_AWAY = "OEMHomeAway"
+    OEM_RANDOM = "OEMRandom"
+    OEM_RANDOM_TOGGLE = "OEMRandomToggle"
+    OEM_TIMER = "OEMTimer"
+    OEM_WALK_AWAY = "OEMWalkAway"
     SET_BREEZE = "SetBreeze"
     SET_DIRECTION = "SetDirection"
+    SET_SPEED = "SetSpeed"
     TOGGLE_DIRECTION = "ToggleDirection"
+    TOGGLE_LIGHT_TEMP = "ToggleLightTemp"
 
     # Fireplaces
     INCREASE_TEMPERATURE = "IncreaseTemperature"
@@ -72,12 +84,32 @@ class Action:
     SET_FLAME = "SetFlame"
 
     # Motorized Shades
-    OPEN = "Open"
     CLOSE = "Close"
-    TILT_OPEN = "TiltOpen"
-    TILT_CLOSE = "TiltClose"
+    CLOSE_NEXT = "CloseNext"
+    DECREASE_POSITION = "DecreasePosition"
+    ESC = "Esc"
     HOLD = "Hold"
+    INCREASE_POSITION = "IncreasePosition"
+    LONG_CLOSE = "LongClose"
+    LONG_HOLD = "LongHold"
+    LONG_OPEN = "LongOpen"
+    LONG_PAIR = "LongPair"
+    OPEN = "Open"
+    OPEN_NEXT = "OpenNext"
     PAIR = "Pair"
+    PRESET = "Preset"
+    SAVE_LIMIT_BOTTOM_OEM = "SaveLimitBottomOEM"
+    SAVE_LIMIT_TOP_OEM = "SaveLimitTopOEM"
+    SET_LIMIT_BOTTOM_OEM = "SetLimitBottomOEM"
+    SET_LIMIT_TOP_OEM = "SetLimitTopOEM"
+    SET_POSITION = "SetPosition"
+    TILT_CLOSE = "TiltClose"
+    TILT_LEFT = "TiltLeft"
+    TILT_LEFT_LONG = "TiltLeftLong"
+    TILT_OPEN = "TiltOpen"
+    TILT_RIGHT = "TiltRight"
+    TILT_RIGHT_LONG = "TiltRightLong"
+    TILT_STOP = "TiltStop"
     TOGGLE_OPEN = "ToggleOpen"
 
     def __init__(self, name: str, argument: Any = None):
@@ -165,6 +197,21 @@ class Action:
         """Sets brightness of the light as percentage value, 1-100."""
         return Action(Action.SET_BRIGHTNESS, brightness)
 
+    @staticmethod
+    def set_color_temperature(temperature: int) -> "Action":
+        """Sets color temperature of the light in Kelin. Resolution: 100 K."""
+        return Action(Action.SET_COLOR_TEMP, temperature)
+
+    @staticmethod
+    def increase_color_temperature(temperature: int) -> "Action":
+        """Increases color temperature a specified number of degrees K. Implicitly turn Light on."""
+        return Action(Action.INCREASE_COLOR_TEMP, temperature)
+
+    @staticmethod
+    def decrease_color_temperature(temperature: int) -> "Action":
+        """Decreases color temperature a specified number of degrees K. Implicitly turn Light on."""
+        return Action(Action.DECREASE_COLOR_TEMP, temperature)
+
     @staticmethod
     def set_brightness_belief(brightness: int) -> "Action":
         """Sets brightness belief of the light as percentage value, 1-100."""
@@ -175,6 +222,21 @@ class Action:
         """Sets the flame to given intensity in percent."""
         return Action(Action.SET_FLAME, flame)
 
+    @staticmethod
+    def set_position(position: int) -> "Action":
+        """Sets shade position percentage from 0 (open) to 100 (closed)."""
+        return Action(Action.SET_POSITION, position)
+
+    @staticmethod
+    def increase_position(position: int) -> "Action":
+        """Closes the device by the specified percentage of the full range."""
+        return Action(Action.INCREASE_POSITION, position)
+
+    @staticmethod
+    def decrease_position(position: int) -> "Action":
+        """Opens the device by the specified percentage of the full range."""
+        return Action(Action.DECREASE_POSITION, position)
+
     @property
     def name(self) -> str:
         """Return name of this action."""
